"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var common = require("./image-cache-it.common");
var image_cache_it_common_1 = require("./image-cache-it.common");
var fs = require("tns-core-modules/file-system");
var utils = require("tns-core-modules/utils/utils");
var types = require("tns-core-modules/utils/types");
var view_1 = require("tns-core-modules/ui/core/view");
var app = require("tns-core-modules/application");
var image_source_1 = require("tns-core-modules/image-source");
var background_1 = require("tns-core-modules/ui/styling/background");
global.moduleMerge(common, exports);
var ImageCacheIt = (function (_super) {
    __extends(ImageCacheIt, _super);
    function ImageCacheIt() {
        var _this = _super.call(this) || this;
        _this.emptyBackground = new background_1.Background();
        return _this;
    }
    ImageCacheIt.prototype.createNativeView = function () {
        return new com.github.triniwiz.imagecacheit.ImageView(this._context, null);
    };
    ImageCacheIt.prototype.initNativeView = function () {
        this.style.backgroundInternal = this.emptyBackground;
        ImageCacheIt._setPlaceHolder(this.placeHolder, this.nativeView);
        ImageCacheIt._setErrorHolder(this.errorHolder, this.nativeView);
        ImageCacheIt._setFallback(this.fallback, this.nativeView);
        var image = ImageCacheIt.getImage(this.src);
        if (types.isString(image) && this.nativeView) {
            this.nativeView.setUriSrc(android.net.Uri.parse(image));
        }
        else if (types.isNumber(image) || image instanceof java.lang.Integer) {
            this.nativeView.setIdSrc(image);
        }
        else if (image instanceof java.io.File) {
            this.nativeView.setUriSrc(android.net.Uri.parse(image.getAbsolutePath()));
        }
    };
    ImageCacheIt.prototype.disposeNativeView = function () {
        _super.prototype.disposeNativeView.call(this);
    };
    ImageCacheIt.prototype[view_1.borderTopColorProperty.setNative] = function (color) {
        if (color) {
            this.nativeView.setBorderTopColor(color.android);
        }
    };
    ImageCacheIt.prototype[view_1.borderRightColorProperty.setNative] = function (color) {
        if (color) {
            this.nativeView.setBorderRightColor(color.android);
        }
    };
    ImageCacheIt.prototype[view_1.borderBottomColorProperty.setNative] = function (color) {
        if (color) {
            this.nativeView.setBorderBottomColor(color.android);
        }
    };
    ImageCacheIt.prototype[view_1.borderLeftColorProperty.setNative] = function (color) {
        if (color) {
            this.nativeView.setBorderLeftColor(color.android);
        }
    };
    ImageCacheIt.prototype[view_1.borderTopWidthProperty.setNative] = function (width) {
        var px = utils.layout.toDevicePixels(width);
        if (isNaN(px)) {
            px = 0;
        }
        this.nativeView.setBorderTopWidth(px);
    };
    ImageCacheIt.prototype[view_1.borderRightWidthProperty.setNative] = function (width) {
        var px = utils.layout.toDevicePixels(width);
        if (isNaN(px)) {
            px = 0;
        }
        this.nativeView.setBorderRightWidth(px);
    };
    ImageCacheIt.prototype[view_1.borderBottomWidthProperty.setNative] = function (width) {
        var px = utils.layout.toDevicePixels(width);
        if (isNaN(px)) {
            px = 0;
        }
        this.nativeView.setBorderBottomWidth(px);
    };
    ImageCacheIt.prototype[view_1.borderLeftWidthProperty.setNative] = function (width) {
        var px = utils.layout.toDevicePixels(width);
        if (isNaN(px)) {
            px = 0;
        }
        this.nativeView.setBorderLeftWidth(px);
    };
    ImageCacheIt.prototype[view_1.borderTopLeftRadiusProperty.setNative] = function (radius) {
        var px = utils.layout.toDevicePixels(radius);
        if (isNaN(px)) {
            px = 0;
        }
        this.nativeView.setBorderTopLeftRadius(px);
    };
    ImageCacheIt.prototype[view_1.borderTopRightRadiusProperty.setNative] = function (radius) {
        var px = utils.layout.toDevicePixels(radius);
        if (isNaN(px)) {
            px = 0;
        }
        this.nativeView.setBorderTopRightRadius(px);
    };
    ImageCacheIt.prototype[view_1.borderBottomLeftRadiusProperty.setNative] = function (radius) {
        var px = utils.layout.toDevicePixels(radius);
        if (isNaN(px)) {
            px = 0;
        }
        this.nativeView.setBorderBottomLeftRadius(px);
    };
    ImageCacheIt.prototype[view_1.borderBottomRightRadiusProperty.setNative] = function (radius) {
        var px = utils.layout.toDevicePixels(radius);
        if (isNaN(px)) {
            px = 0;
        }
        this.nativeView.setBorderBottomRightRadius(px);
    };
    ImageCacheIt.prototype[image_cache_it_common_1.filterProperty.setNative] = function (filter) {
        if (this.nativeView) {
            this.nativeView.setFilter(filter);
        }
    };
    ImageCacheIt.isNumber = function (value) {
        return typeof value === 'number';
    };
    ImageCacheIt.getResourceId = function (res) {
        if (res === void 0) { res = ''; }
        if (types.isString(res) && res.startsWith('res://')) {
            return java.lang.Integer.valueOf(utils.ad.resources.getDrawableId(res.replace('res://', '')));
        }
        return java.lang.Integer.valueOf(0);
    };
    ImageCacheIt._setFallback = function (fallback, nativeView) {
        var holder = ImageCacheIt.getImage(fallback);
        if (nativeView) {
            if (types.isString(fallback) && fallback.startsWith('res://')) {
                nativeView.setErrorHolder(fallback);
            }
            else {
                nativeView.setErrorHolder(holder);
            }
        }
    };
    ImageCacheIt.prototype[common.fallbackProperty.setNative] = function (fallback) {
        ImageCacheIt._setFallback(fallback, this.nativeView);
    };
    ImageCacheIt._setPlaceHolder = function (placeHolder, nativeView) {
        var holder = ImageCacheIt.getImage(placeHolder);
        if (nativeView) {
            if (types.isString(placeHolder) && placeHolder.startsWith('res://')) {
                nativeView.setPlaceHolder(placeHolder);
            }
            else {
                nativeView.setPlaceHolder(holder);
            }
        }
    };
    ImageCacheIt.prototype[common.placeHolderProperty.setNative] = function (placeHolder) {
        ImageCacheIt._setPlaceHolder(placeHolder, this.nativeView);
    };
    ImageCacheIt._setErrorHolder = function (errorHolder, nativeView) {
        var holder = ImageCacheIt.getImage(errorHolder);
        if (nativeView) {
            if (types.isString(errorHolder) && errorHolder.startsWith('res://')) {
                nativeView.setErrorHolder(errorHolder);
            }
            else {
                nativeView.setErrorHolder(holder);
            }
        }
    };
    ImageCacheIt.prototype[common.errorHolderProperty.setNative] = function (errorHolder) {
        ImageCacheIt._setErrorHolder(errorHolder, this.nativeView);
    };
    ImageCacheIt.prototype[common.srcProperty.getDefault] = function () {
        return undefined;
    };
    ImageCacheIt._setSrc = function (src, nativeView) {
        var image = ImageCacheIt.getImage(src);
        if (nativeView) {
            if (types.isString(image)) {
                nativeView.setUriSrc(android.net.Uri.parse(image));
            }
            else if (types.isNumber(image) || image instanceof java.lang.Integer) {
                nativeView.setIdSrc(image);
            }
            else if (image instanceof java.io.File) {
                nativeView.setFileSrc(image);
            }
            else {
                nativeView.setBitmapSrc(image);
            }
        }
    };
    ImageCacheIt.prototype[common.srcProperty.setNative] = function (src) {
        ImageCacheIt._setSrc(src, this.nativeView);
    };
    ImageCacheIt.prototype[common.decodedWidthProperty.setNative] = function (width) {
    };
    ImageCacheIt.prototype[common.decodedHeightProperty.setNative] = function (height) {
    };
    ImageCacheIt.getImage = function (src) {
        var nativeImage = null;
        if (types.isNullOrUndefined(src)) {
            return null;
        }
        if (types.isString(src)) {
            if (src.substr(0, 1) === '/') {
                nativeImage = new java.io.File(src);
            }
            else if (src.startsWith('~/')) {
                nativeImage = new java.io.File(fs.path.join(fs.knownFolders.currentApp().path, src.replace('~/', '')));
            }
            else if (src.startsWith('http')) {
                nativeImage = src;
            }
            else if (src.startsWith('res://')) {
                nativeImage = this.getResourceId(src);
            }
        }
        else if (src instanceof image_source_1.ImageSource) {
            nativeImage = src.android;
        }
        else {
            nativeImage = src;
        }
        return nativeImage;
    };
    ImageCacheIt.prototype[common.filterProperty.setNative] = function (filter) {
        if (this.nativeView) {
            this.nativeView.setFilter(filter);
        }
    };
    ImageCacheIt.prototype[common.stretchProperty.getDefault] = function () {
        return 'aspectFit';
    };
    ImageCacheIt.prototype[common.stretchProperty.setNative] = function (value) {
        if (this.nativeView) {
            switch (this.stretch) {
                case 'aspectFit':
                    this.nativeView.setScaleType(android.widget.ImageView.ScaleType.FIT_CENTER);
                    break;
                case 'aspectFill':
                    this.nativeView.setScaleType(android.widget.ImageView.ScaleType.CENTER_CROP);
                    break;
                case 'fill':
                    this.nativeView.setScaleType(android.widget.ImageView.ScaleType.FIT_XY);
                    break;
                case 'none':
                default:
                    this.nativeView.setScaleType(android.widget.ImageView.ScaleType.MATRIX);
                    break;
            }
        }
    };
    ImageCacheIt.getItem = function (src) {
        com.github.triniwiz.imagecacheit.ImageCache.init(app.android.context);
        return new Promise(function (resolve, reject) {
            com.github.triniwiz.imagecacheit.ImageCache.getItem(src, null, new com.github.triniwiz.imagecacheit.ImageCache.Callback({
                onSuccess: function (value) {
                    resolve(value);
                },
                onError: function (error) {
                    reject(error.getMessage());
                }
            }));
        });
    };
    ImageCacheIt.deleteItem = function (src) {
        return new Promise(function (resolve, reject) {
            resolve();
        });
    };
    ImageCacheIt.hasItem = function (src) {
        com.github.triniwiz.imagecacheit.ImageCache.init(app.android.context);
        return new Promise(function (resolve, reject) {
            com.github.triniwiz.imagecacheit.ImageCache.hasItem(src, new com.github.triniwiz.imagecacheit.ImageCache.Callback({
                onSuccess: function (value) {
                    resolve();
                },
                onError: function (error) {
                    reject(error.getMessage());
                }
            }));
        });
    };
    ImageCacheIt.clear = function () {
        com.github.triniwiz.imagecacheit.ImageCache.init(app.android.context);
        return new Promise(function (resolve, reject) {
            com.github.triniwiz.imagecacheit.ImageCache.clear();
            resolve();
        });
    };
    ImageCacheIt.enableAutoMM = function () {
        com.github.triniwiz.imagecacheit.ImageView.enableAutoMM(app.android.nativeApp);
    };
    ImageCacheIt.disableAutoMM = function () {
        com.github.triniwiz.imagecacheit.ImageView.disableAutoMM(app.android.nativeApp);
    };
    return ImageCacheIt;
}(image_cache_it_common_1.ImageCacheItBase));
exports.ImageCacheIt = ImageCacheIt;
//# sourceMappingURL=image-cache-it.android.js.map